@@ -26,6 +26,7 @@
 #' @param expedite Set to TRUE to expedite the processing of this report
 #' @param interval.seconds How long to wait between attempts
 #' @param max.attempts Number of API attempts before stopping
+#' @param validate Weather to submit report definition for validation before requesting the data.
 #'
 #' @importFrom jsonlite toJSON unbox
 #'
@@ -48,7 +49,7 @@
 
 QueuePathing <- function(reportsuite.id, date.from, date.to, metric, element, pattern,
                         top=1000, start=1,
-                        segment.id='', expedite=FALSE,interval.seconds=5,max.attempts=120) {
+                        segment.id='', expedite=FALSE,interval.seconds=5,max.attempts=120,validate=TRUE) {
   
   # build JSON description
   # we have to use unbox to force jsonlist not put strings into single-element arrays
@@ -69,7 +70,7 @@ QueuePathing <- function(reportsuite.id, date.from, date.to, metric, element, pa
                                                             startingWith = unbox(start), 
                                                             pattern = as.list(pattern)))
 
-  report.data <- SubmitJsonQueueReport(toJSON(report.description),interval.seconds=interval.seconds,max.attempts=max.attempts)
+  report.data <- SubmitJsonQueueReport(toJSON(report.description),interval.seconds=interval.seconds,max.attempts=max.attempts,validate=validate)
 
   return(report.data) 
 
